@@ -401,6 +401,11 @@ def _str_or_na(arg: str) -> Optional[str]:
         return None
     return arg
 
+def _int_or_na(arg: str) -> Optional[int]:
+    if arg == '(n/a)':
+        return None
+    return int(arg)
+
 def _parse_modified(arg: str) -> Optional[datetime]:
     try:
         return datetime.fromisoformat(arg)
@@ -411,7 +416,7 @@ def _parse_modified(arg: str) -> Optional[datetime]:
 _ARCLS_COLUMNS: Dict[str, Tuple[str, Callable[[str], Any]]] = {
     '<Name>': ('name', str),
     '<Type>': ('type_', file_type_of_str),
-    '<Size>': ('size', int),
+    '<Size>': ('size', _int_or_na),
     '<Modified>': ('modified', _parse_modified),
     '<CheckSum>': ('checksum', _str_or_na),
     '<Latency>': ('latency', _str_or_na)
